#Airports master

#This script runs all the functions in linear order

####Setup####

library(stringr)
library(Rblpapi)
library(dplyr)
library(zoo)
library(tidyr)
library(janitor) 
library(lubridate) 
library(data.table)
library(purrr)

Firms <- read.csv("Data/Firms_Airport.csv") |> # header = TRUE, stringsAsFactors = FALSE, strip.white = TRUE) |> 
  mutate(Sample_2020 = Sample_2022)    

# Run using all firms (restriction to sample happens later when analysing results); Alternatively restrict to final sample or AIAL for calculating asset betas
Firms <- data.table(Firms)
#Firms <- Firms[Code %in% c("357 HK Equity","694 HK Equity","ADP FP Equity","AENA SM Equity","AIA NZ Equity","AOT TB Equity","FHZN SW Equity","FRA GR Equity","SYD AU Equity")] #This is the final sample

#Loop through the different time periods

source("Airport analysis/Estimate_daily.R")
source("Airport analysis/Estimate_weekly.R")
source("Airport analysis/Estimate_fourWeekly.R")

DateEnds <- list("30/09/2012","30/09/2017","30/09/2022","28/02/2020","30/09/2022", "30/09/2022")
DateStarts <- list("01/10/2007","01/10/2012","01/10/2017","01/10/2017","01/03/2020", "01/10/2021")

 for (j in 1:6) {
   EndDate <- dmy(DateEnds[j])
   StartDate <- dmy(DateStarts[j])
   Sample <- format(EndDate, format = "%Y")

    EstimateDaily(EndDate,StartDate,Sample,Firms)
    EstimateWeekly(EndDate,StartDate,Sample,Firms)
    EstimateFourWeekly(EndDate,StartDate,Sample,Firms)
}

#Analyse results

#Read in data
DateEnds <- list("2012-09-30","2017-09-30","2022-09-30","2020-02-28","2022-09-30", "2022-09-30") 
DateStarts <- list("2007-10-01","2012-10-01","2017-10-01","2017-10-01","2020-03-01","2021-10-01")

text_location <- "Airport analysis/Results/"

data1 <- fread(paste(text_location,"StartDate-",DateStarts[1],"EndDate-",DateEnds[1],"-Daily-Results.csv",sep=""))
data2 <- fread(paste(text_location,"StartDate-",DateStarts[2],"EndDate-",DateEnds[2],"-Daily-Results.csv",sep=""))
data3 <- fread(paste(text_location,"StartDate-",DateStarts[3],"EndDate-",DateEnds[3],"-Daily-Results.csv",sep=""))
data4 <- fread(paste(text_location,"StartDate-",DateStarts[4],"EndDate-",DateEnds[4],"-Daily-Results.csv",sep=""))
data5 <- fread(paste(text_location,"StartDate-",DateStarts[5],"EndDate-",DateEnds[5],"-Daily-Results.csv",sep=""))
data6 <- fread(paste(text_location,"StartDate-",DateStarts[6],"EndDate-",DateEnds[6],"-Daily-Results.csv",sep=""))


data7 <- fread(paste(text_location,"StartDate-",DateStarts[1],"EndDate-",DateEnds[1],"-Weekly-Results.csv",sep=""))
data8 <- fread(paste(text_location,"StartDate-",DateStarts[2],"EndDate-",DateEnds[2],"-Weekly-Results.csv",sep=""))
data9 <- fread(paste(text_location,"StartDate-",DateStarts[3],"EndDate-",DateEnds[3],"-Weekly-Results.csv",sep=""))
data10 <- fread(paste(text_location,"StartDate-",DateStarts[4],"EndDate-",DateEnds[4],"-Weekly-Results.csv",sep=""))
data11 <- fread(paste(text_location,"StartDate-",DateStarts[5],"EndDate-",DateEnds[5],"-Weekly-Results.csv",sep=""))
data12 <- fread(paste(text_location,"StartDate-",DateStarts[6],"EndDate-",DateEnds[6],"-Weekly-Results.csv",sep=""))


data13 <- fread(paste(text_location,"StartDate-",DateStarts[1],"EndDate-",DateEnds[1],"-FourWeekly-Results.csv",sep=""))
data14 <- fread(paste(text_location,"StartDate-",DateStarts[2],"EndDate-",DateEnds[2],"-FourWeekly-Results.csv",sep=""))
data15 <- fread(paste(text_location,"StartDate-",DateStarts[3],"EndDate-",DateEnds[3],"-FourWeekly-Results.csv",sep=""))
data16 <- fread(paste(text_location,"StartDate-",DateStarts[4],"EndDate-",DateEnds[4],"-FourWeekly-Results.csv",sep=""))
data17 <- fread(paste(text_location,"StartDate-",DateStarts[5],"EndDate-",DateEnds[5],"-FourWeekly-Results.csv",sep=""))
data18 <- fread(paste(text_location,"StartDate-",DateStarts[6],"EndDate-",DateEnds[6],"-FourWeekly-Results.csv",sep=""))

data1 <- data1[,c(1,5,7)]
data2 <- data2[,c(1,5,7)]
data3 <- data3[,c(1,5,7)]
data4 <- data4[,c(1,5,7)]
data5 <- data5[,c(1,5,7)]
data6 <- data6[,c(1,5,7)]
data7 <- data7[,c(1,2,3)]
data8 <- data8[,c(1,2,3)]
data9 <- data9[,c(1,2,3)]
data10 <- data10[,c(1,2,3)]
data11 <- data11[,c(1,2,3)]
data12 <- data12[,c(1,2,3)]
data13 <- data13[,c(1,2,3)]
data14 <- data14[,c(1,2,3)]
data15 <- data15[,c(1,2,3)]
data16 <- data16[,c(1,2,3)]
data17 <- data17[,c(1,2,3)]
data18 <- data18[,c(1,2,3)]


setnames(data1,"Assetbeta","DailyP1A")
setnames(data2,"Assetbeta","DailyP2A")
setnames(data3,"Assetbeta","DailyP3A")
setnames(data4,"Assetbeta","DailyP4A")
setnames(data5,"Assetbeta","DailyP5A")
setnames(data6,"Assetbeta","DailyP6A")
setnames(data7,"Assetbeta","WeeklyP1A")
setnames(data8,"Assetbeta","WeeklyP2A")
setnames(data9,"Assetbeta","WeeklyP3A")
setnames(data10,"Assetbeta","WeeklyP4A")
setnames(data11,"Assetbeta","WeeklyP5A")
setnames(data12,"Assetbeta","WeeklyP6A")
setnames(data13,"Assetbeta","FourWeeklyP1A")
setnames(data14,"Assetbeta","FourWeeklyP2A")
setnames(data15,"Assetbeta","FourWeeklyP3A")
setnames(data16,"Assetbeta","FourWeeklyP4A")
setnames(data17,"Assetbeta","FourWeeklyP5A")
setnames(data18,"Assetbeta","FourWeeklyP6A")

setnames(data1,"AverageGearingDV","DailyP1L")
setnames(data2,"AverageGearingDV","DailyP2L")
setnames(data3,"AverageGearingDV","DailyP3L")
setnames(data4,"AverageGearingDV","DailyP4L")
setnames(data5,"AverageGearingDV","DailyP5L")
setnames(data6,"AverageGearingDV","DailyP6L")
setnames(data7,"gearingDV","WeeklyP1L")
setnames(data8,"gearingDV","WeeklyP2L")
setnames(data9,"gearingDV","WeeklyP3L")
setnames(data10,"gearingDV","WeeklyP4L")
setnames(data11,"gearingDV","WeeklyP5L")
setnames(data12,"gearingDV","WeeklyP6L")
setnames(data13,"gearingDV","FourWeeklyP1L")
setnames(data14,"gearingDV","FourWeeklyP2L")
setnames(data15,"gearingDV","FourWeeklyP3L")
setnames(data16,"gearingDV","FourWeeklyP4L")
setnames(data17,"gearingDV","FourWeeklyP5L")
setnames(data18,"gearingDV","FourWeeklyP6L")

setkey(data1, Code)
setkey(data2, Code)
setkey(data3, Code)
setkey(data4, Code)
setkey(data5, Code)
setkey(data6, Code)
setkey(data7, Code)
setkey(data8, Code)
setkey(data9, Code)
setkey(data10, Code)
setkey(data11, Code)
setkey(data12, Code)
setkey(data13, Code)
setkey(data14, Code)
setkey(data15, Code)
setkey(data16, Code)
setkey(data17, Code)
setkey(data18, Code)

setorder(data1, Code)
setorder(data2, Code)
setorder(data3, Code)
setorder(data4, Code)
setorder(data5, Code)
setorder(data6, Code)
setorder(data7, Code)
setorder(data8, Code)
setorder(data9, Code)
setorder(data10, Code)
setorder(data11, Code)
setorder(data12, Code)
setorder(data13, Code)
setorder(data14, Code)
setorder(data15, Code)
setorder(data16, Code)
setorder(data17, Code)
setorder(data18, Code)

data_a = list(data1,data2,data7,data8,data13,data14)
Results_a <- purrr::reduce(data_a,dplyr::full_join,by="Code")

data_b = list(data3,data4,data5,data6,data9,data10,data11,data12,data15,data16,data17,data18)
Results_b <- purrr::reduce(data_b,dplyr::full_join,by="Code")

Results <- left_join(Results_b,Results_a, by="Code")

#Add names
AirportNames <- fread("data/AirportNames.csv")
Results <- left_join(Results,AirportNames, by="Code")

#Add back equity betas
Results$DailyP1E <- Results$DailyP1A / (1-Results$DailyP1L)
Results$DailyP2E <- Results$DailyP2A / (1-Results$DailyP2L)
Results$DailyP3E <- Results$DailyP3A / (1-Results$DailyP3L)
Results$DailyP4E <- Results$DailyP4A / (1-Results$DailyP4L)
Results$DailyP5E <- Results$DailyP5A / (1-Results$DailyP5L)
Results$DailyP6E <- Results$DailyP6A / (1-Results$DailyP6L)

Results$WeeklyP1E <- Results$WeeklyP1A / (1-Results$WeeklyP1L)
Results$WeeklyP2E <- Results$WeeklyP2A / (1-Results$WeeklyP2L)
Results$WeeklyP3E <- Results$WeeklyP3A / (1-Results$WeeklyP3L)
Results$WeeklyP4E <- Results$WeeklyP4A / (1-Results$WeeklyP4L)
Results$WeeklyP5E <- Results$WeeklyP5A / (1-Results$WeeklyP5L)
Results$WeeklyP6E <- Results$WeeklyP6A / (1-Results$WeeklyP6L)

Results$FourWeeklyP1E <- Results$FourWeeklyP1A / (1-Results$FourWeeklyP1L)
Results$FourWeeklyP2E <- Results$FourWeeklyP2A / (1-Results$FourWeeklyP2L)
Results$FourWeeklyP3E <- Results$FourWeeklyP3A / (1-Results$FourWeeklyP3L)
Results$FourWeeklyP4E <- Results$FourWeeklyP4A / (1-Results$FourWeeklyP4L)
Results$FourWeeklyP5E <- Results$FourWeeklyP5A / (1-Results$FourWeeklyP5L)
Results$FourWeeklyP6E <- Results$FourWeeklyP6A / (1-Results$FourWeeklyP6L)

#Identify firms with negative leverage
Results$WeeklyP1LW <- Results$WeeklyP1L * 1826/4533 
Results$WeeklyP2LW <- Results$WeeklyP2L * 1826/4533 
Results$WeeklyP4LW <- Results$WeeklyP4L * 880/4533 
Temp1 <- Results[, .(PreCovidWeeklyL = sum(c(WeeklyP1LW,WeeklyP2LW,WeeklyP4LW),na.rm=TRUE)), by=Code]
Results <- Results[Temp1,]

#Identify firms with substantial variability in betas
Results[, MaxP2 := pmax(WeeklyP2A,FourWeeklyP2A,na.rm=TRUE), by=Code]
Results[, MaxP3 := pmax(WeeklyP3A,FourWeeklyP3A,na.rm=TRUE), by=Code]

Results[, MinP2 := pmin(WeeklyP2A,FourWeeklyP2A,na.rm=TRUE), by=Code]
Results[, MinP3 := pmin(WeeklyP3A,FourWeeklyP3A,na.rm=TRUE), by=Code]

Results[, VariationP2 := MaxP2 - MinP2]
Results[, VariationP3 := MaxP3 - MinP3]

Results <- Results[, MaxVariation := pmax(VariationP2,VariationP3,na.rm=TRUE), by=Code]

#Add liquidity and market comparability data
Indicators <- fread("Data/Liquidity and market.csv")
Indicators$Bid_ask_spread[is.na(Indicators$Bid_ask_spread)] <- NA
Indicators$Free_float[is.na(Indicators$Free_float)] <- NA
Indicators1 <- left_join(Results, Indicators, by = "Code")

#Exclude firms not in the final sample

Final <- Indicators1
Final$select <- ifelse (Final$Code %in% c("357 HK Equity","694 HK Equity","ADP FP Equity","AENA SM Equity","AIA NZ Equity","AOT TB Equity","FHZN SW Equity","FRA GR Equity","SYD AU Equity"),1,0)
Final <- Final[select==1]

#Calculate mean asset betas
DailyP1A.mean = mean(Final$DailyP1A,na.rm=TRUE)
DailyP2A.mean = mean(Final$DailyP2A,na.rm=TRUE)
DailyP3A.mean = mean(Final$DailyP3A,na.rm=TRUE)
DailyP4A.mean = mean(Final$DailyP4A,na.rm=TRUE)
DailyP5A.mean = mean(Final$DailyP5A,na.rm=TRUE)

WeeklyP1A.mean = mean(Final$WeeklyP1A,na.rm=TRUE)
WeeklyP2A.mean = mean(Final$WeeklyP2A,na.rm=TRUE)
WeeklyP3A.mean = mean(Final$WeeklyP3A,na.rm=TRUE)
WeeklyP4A.mean = mean(Final$WeeklyP4A,na.rm=TRUE)
WeeklyP5A.mean = mean(Final$WeeklyP5A,na.rm=TRUE)

FourWeeklyP1A.mean = mean(Final$FourWeeklyP1A,na.rm=TRUE)
FourWeeklyP2A.mean = mean(Final$FourWeeklyP2A,na.rm=TRUE)
FourWeeklyP3A.mean = mean(Final$FourWeeklyP3A,na.rm=TRUE)
FourWeeklyP4A.mean = mean(Final$FourWeeklyP4A,na.rm=TRUE)
FourWeeklyP5A.mean = mean(Final$FourWeeklyP5A,na.rm=TRUE)

#Calculate the pre-Covid asset beta

PreCovid1A = mean(WeeklyP1A.mean,FourWeeklyP1A.mean) * 1826/4533
PreCovid2A = mean(WeeklyP2A.mean,FourWeeklyP1A.mean) * 1826/4533
PreCovid3A = mean(WeeklyP4A.mean,FourWeeklyP4A.mean) * 880/4533

PreCovidA = sum(PreCovid1A,PreCovid2A,PreCovid3A)
PreCovidA

#Calculate the pre-Covid equity beta

WeeklyP1E.mean = mean(Final$WeeklyP1E,na.rm=TRUE)
FourWeeklyP1E.mean = mean(Final$FourWeeklyP1A,na.rm=TRUE)
WeeklyP2E.mean = mean(Final$WeeklyP2E,na.rm=TRUE)
FourWeeklyP2E.mean = mean(Final$FourWeeklyP2E,na.rm=TRUE)
WeeklyP4E.mean = mean(Final$WeeklyP4E,na.rm=TRUE)
FourWeeklyP4E.mean = mean(Final$FourWeeklyP4E,na.rm=TRUE)

PreCovid1E = mean(WeeklyP1E.mean,FourWeeklyP1E.mean) * 1826/4533
PreCovid2E = mean(WeeklyP2E.mean,FourWeeklyP1E.mean) * 1826/4533
PreCovid3E = mean(WeeklyP4E.mean,FourWeeklyP4E.mean) * 880/4533

PreCovidE = sum(PreCovid1E,PreCovid2E,PreCovid3E)
PreCovidE

#Calculate the pre-Covid leverage

WeeklyP1L.mean = mean(Final$WeeklyP1L,na.rm=TRUE)
FourWeeklyP1L.mean = mean(Final$FourWeeklyP1L,na.rm=TRUE)
WeeklyP2L.mean = mean(Final$WeeklyP2L,na.rm=TRUE)
FourWeeklyP2L.mean = mean(Final$FourWeeklyP2L,na.rm=TRUE)
WeeklyP4L.mean = mean(Final$WeeklyP4L,na.rm=TRUE)
FourWeeklyP4L.mean = mean(Final$FourWeeklyP4L,na.rm=TRUE)

PreCovidL1 <- mean(WeeklyP1L.mean,FourWeeklyP1L.mean) * 1826/4533 
PreCovidL2 <- mean(WeeklyP2L.mean,FourWeeklyP2L.mean) * 1826/4533 
PreCovidL4 <- mean(WeeklyP4L.mean,FourWeeklyP4L.mean) * 880/4533

PreCovid_leverage = sum(PreCovidL1,PreCovidL2,PreCovidL4)

PreCovid_leverage

Summary <- Final[,.(Code,PreCovidA,PreCovid_leverage)]
write.csv(Summary,"Airport analysis/Results/PreCovid_betas.csv")

#Calculate the last 12 months asset beta and leverage
Final[, Last12A := mean(c(WeeklyP6A,FourWeeklyP6A),na.rm=TRUE), by=Code]
Final[, Last12L := mean(c(WeeklyP6L,FourWeeklyP6L),na.rm=TRUE), by=Code]
Last_12_beta <- mean(Final$Last12A, na.rm=TRUE)
Last_12_leverage <- mean(Final$Last12L, na.rm=TRUE)
Last_12_beta
Last_12_leverage

Summary <- Final[,.(Code,Last12A,Last12L)]
write.csv(Summary,"Airport analysis/Results/Last12_betas.csv")

#Calculate the last two 5-years asset beta and leverage for the final sample
Final[, last2fiveA := mean(c(WeeklyP2A,FourWeeklyP2A,WeeklyP3A,FourWeeklyP3A),na.rm=TRUE), by=Code]
Final[, last2fiveL := mean(c(WeeklyP2L,FourWeeklyP2L,WeeklyP3L,FourWeeklyP3L),na.rm=TRUE), by=Code]

mean_last_two_five_beta <- mean(Final$last2fiveA)
mean_last_two_five_leverage <- mean(Final$last2fiveL)
mean_last_two_five_beta
mean_last_two_five_leverage

Summary <- Final[,.(Code,last2fiveA,last2fiveL)]
write.csv(Summary,"Airport analysis/Results/Last_two_five_betas.csv")

#Calculate the last two 5-years leverage for the full sample
setDT(Indicators1)[, last2fiveL := mean(c(WeeklyP2L,FourWeeklyP2L,WeeklyP3L,FourWeeklyP3L),na.rm=TRUE), by=Code]

#Tables for appendices

Table_D1 <- Indicators1[,.(Code, Name,VariationP2, VariationP3,Bid_ask_spread, Free_float, PreCovidWeeklyL, last2fiveL, Country_classification)]
Table_D1$select <- ifelse (Table_D1$Code %in% c("357 HK Equity","694 HK Equity","ADP FP Equity","AENA SM Equity","AIA NZ Equity","AOT TB Equity","FHZN SW Equity","FRA GR Equity","SYD AU Equity"),1,0)
Table_D1$VariationP2 <- format(round(Table_D1$VariationP2,digits=2),nsmall=2)
Table_D1$VariationP3 <- format(round(Table_D1$VariationP3,digits=2),nsmall=2)
Table_D1$PreCovidWeeklyL <- format(round(Table_D1$PreCovidWeeklyL,digits=2),nsmall=2)
Table_D1$last2fiveL <- format(round(Table_D1$last2fiveL,digits=2),nsmall=2)
Table_D1 <- setNames(Table_D1,c("Ticker","Name","Asset beta variability 2012-17","Asset beta variability 2017-22","Bid-ask spread","Free float","PC Leverage","Last two-five leverage","Country classification","In or out"))
Table_D1$`Asset beta variability 2012-17`[Table_D1$`Asset beta variability 2012-17` == "-Inf"] <- NA
Table_D1 <- arrange(Table_D1,desc(Table_D1$`In or out`))

Table_D2 <- as.data.table(matrix(nrow=4,ncol=6))
Table_D2 <- setNames(Table_D2,c("Frequency","2007-12","2012-17","2017-22","2017-20","2020-22"))
Table_D2$Frequency <-c("Daily","Weekly","Four-weekly","Average (weekly and four-weekly")

Table_D2[,`2007-12`:=as.numeric(`2007-12`)]
Table_D2[,`2012-17`:=as.numeric(`2012-17`)]
Table_D2[,`2017-22`:=as.numeric(`2017-22`)]
Table_D2[,`2017-20`:=as.numeric(`2017-20`)]
Table_D2[,`2020-22`:=as.numeric(`2020-22`)]

Table_D2[1,"2007-12"] <- DailyP1A.mean
Table_D2[1,"2012-17"] <- DailyP2A.mean
Table_D2[1,"2017-22"] <- DailyP3A.mean
Table_D2[1,"2017-20"] <- DailyP4A.mean
Table_D2[1,"2020-22"] <- DailyP5A.mean

Table_D2[2,"2007-12"] <- WeeklyP1A.mean
Table_D2[2,"2012-17"] <- WeeklyP2A.mean
Table_D2[2,"2017-22"] <- WeeklyP3A.mean
Table_D2[2,"2017-20"] <- WeeklyP4A.mean
Table_D2[2,"2020-22"] <- WeeklyP5A.mean

Table_D2[3,"2007-12"] <- FourWeeklyP1A.mean
Table_D2[3,"2012-17"] <- FourWeeklyP2A.mean
Table_D2[3,"2017-22"] <- FourWeeklyP3A.mean
Table_D2[3,"2017-20"] <- FourWeeklyP4A.mean
Table_D2[3,"2020-22"] <- FourWeeklyP5A.mean

Table_D2[4,"2007-12"] <- mean(c(WeeklyP1A.mean,FourWeeklyP1A.mean))
Table_D2[4,"2012-17"] <- mean(c(WeeklyP2A.mean,FourWeeklyP2A.mean))
Table_D2[4,"2017-22"] <- mean(c(WeeklyP3A.mean,FourWeeklyP3A.mean))
Table_D2[4,"2017-20"] <- mean(c(WeeklyP4A.mean,FourWeeklyP4A.mean))
Table_D2[4,"2020-22"] <- mean(c(WeeklyP5A.mean,FourWeeklyP5A.mean))

Table_D2$`2007-12` <- format(round(Table_D2$`2007-12`,digits=2),nsmall=2)
Table_D2$`2012-17` <- format(round(Table_D2$`2012-17`,digits=2),nsmall=2)
Table_D2$`2017-22` <- format(round(Table_D2$`2017-22`,digits=2),nsmall=2)
Table_D2$`2017-20` <- format(round(Table_D2$`2017-20`,digits=2),nsmall=2)
Table_D2$`2020-22` <- format(round(Table_D2$`2020-22`,digits=2),nsmall=2)

Table_D3 <- Final[,.(Code,Name,DailyP1A,WeeklyP1A,FourWeeklyP1A,DailyP2A,WeeklyP2A,FourWeeklyP2A,DailyP3A,WeeklyP3A,FourWeeklyP3A)]
Table_D3$select <- ifelse (Table_D3$Code %in% c("357 HK Equity","694 HK Equity","ADP FP Equity","AENA SM Equity","AIA NZ Equity","AOT TB Equity","FHZN SW Equity","FRA GR Equity","SYD AU Equity"),0,1)
Table_D3 <- Table_D3[select==0]
Table_D3$select <- NULL
Table_D3 <- setNames(Table_D3,c("Ticker","Name","2007-12 Daily","2007-12 Weekly","2007-12 Four-weekly","2012-17 Daily","2012-17 Weekly","2012-17 Four-weekly","2017-22 Daily","2017-22 Weekly","2017-22 Four-weekly"))

Table_D3$`2007-12 Daily` <- format(round(Table_D3$`2007-12 Daily`,digits=2),nsmall=2)
Table_D3$`2012-17 Daily` <- format(round(Table_D3$`2012-17 Daily`,digits=2),nsmall=2)
Table_D3$`2017-22 Daily` <- format(round(Table_D3$`2017-22 Daily`,digits=2),nsmall=2)

Table_D3$`2007-12 Weekly` <- format(round(Table_D3$`2007-12 Weekly`,digits=2),nsmall=2)
Table_D3$`2012-17 Weekly` <- format(round(Table_D3$`2012-17 Weekly`,digits=2),nsmall=2)
Table_D3$`2017-22 Weekly` <- format(round(Table_D3$`2017-22 Weekly`,digits=2),nsmall=2)

Table_D3$`2007-12 Four-weekly` <- format(round(Table_D3$`2007-12 Four-weekly`,digits=2),nsmall=2)
Table_D3$`2012-17 Four-weekly` <- format(round(Table_D3$`2012-17 Four-weekly`,digits=2),nsmall=2)
Table_D3$`2017-22 Four-weekly` <- format(round(Table_D3$`2017-22 Four-weekly`,digits=2),nsmall=2)

write.csv(Table_D1,"Airport analysis/Results/Table_D1.csv")
write.csv(Table_D2,"Airport analysis/Results/Table_D2.csv")
write.csv(Table_D3,"Airport analysis/Results/Table_D3.csv")


#Standard error analysis

#Read in data
DateEnds <- list("2012-09-30","2017-09-30","2022-09-30","2020-02-28","2022-09-30", "2022-09-30") 
DateStarts <- list("2007-10-01","2012-10-01","2017-10-01","2017-10-01","2020-03-01","2021-10-01")

text_location <- "Airport analysis/Results/"

data1 <- fread(paste(text_location,"StartDate-",DateStarts[1],"EndDate-",DateEnds[1],"-Daily-StandardErrorResults.csv",sep=""))
data2 <- fread(paste(text_location,"StartDate-",DateStarts[2],"EndDate-",DateEnds[2],"-Daily-StandardErrorResults.csv",sep=""))
data3 <- fread(paste(text_location,"StartDate-",DateStarts[3],"EndDate-",DateEnds[3],"-Daily-StandardErrorResults.csv",sep=""))
data4 <- fread(paste(text_location,"StartDate-",DateStarts[4],"EndDate-",DateEnds[4],"-Daily-StandardErrorResults.csv",sep=""))
data5 <- fread(paste(text_location,"StartDate-",DateStarts[5],"EndDate-",DateEnds[5],"-Daily-StandardErrorResults.csv",sep=""))
data6 <- fread(paste(text_location,"StartDate-",DateStarts[6],"EndDate-",DateEnds[6],"-Daily-StandardErrorResults.csv",sep=""))

data7 <- fread(paste(text_location,"StartDate-",DateStarts[1],"EndDate-",DateEnds[1],"-Weekly-StandardErrorResults.csv",sep=""))
data8 <- fread(paste(text_location,"StartDate-",DateStarts[2],"EndDate-",DateEnds[2],"-Weekly-StandardErrorResults.csv",sep=""))
data9 <- fread(paste(text_location,"StartDate-",DateStarts[3],"EndDate-",DateEnds[3],"-Weekly-StandardErrorResults.csv",sep=""))
data10 <- fread(paste(text_location,"StartDate-",DateStarts[4],"EndDate-",DateEnds[4],"-Weekly-StandardErrorResults.csv",sep=""))
data11 <- fread(paste(text_location,"StartDate-",DateStarts[5],"EndDate-",DateEnds[5],"-Weekly-StandardErrorResults.csv",sep=""))
data12 <- fread(paste(text_location,"StartDate-",DateStarts[6],"EndDate-",DateEnds[6],"-Weekly-StandardErrorResults.csv",sep=""))

data13 <- fread(paste(text_location,"StartDate-",DateStarts[1],"EndDate-",DateEnds[1],"-FourWeekly-StandardErrorResults.csv",sep=""))
data14 <- fread(paste(text_location,"StartDate-",DateStarts[2],"EndDate-",DateEnds[2],"-FourWeekly-StandardErrorResults.csv",sep=""))
data15 <- fread(paste(text_location,"StartDate-",DateStarts[3],"EndDate-",DateEnds[3],"-FourWeekly-StandardErrorResults.csv",sep=""))
data16 <- fread(paste(text_location,"StartDate-",DateStarts[4],"EndDate-",DateEnds[4],"-FourWeekly-StandardErrorResults.csv",sep=""))
data17 <- fread(paste(text_location,"StartDate-",DateStarts[5],"EndDate-",DateEnds[5],"-FourWeekly-StandardErrorResults.csv",sep=""))
data18 <- fread(paste(text_location,"StartDate-",DateStarts[6],"EndDate-",DateEnds[6],"-FourWeekly-StandardErrorResults.csv",sep=""))

data1$Period <- "DailyP1SE"
data2$Period <- "DailyP2SE"
data3$Period <- "DailyP3SE"
data4$Period <- "DailyP4SE"
data5$Period <- "DailyP5SE"
data6$Period <- "DailyP6SE"
data7$Period <- "WeeklyP1SE"
data8$Period <- "WeeklyP2SE"
data9$Period <- "WeeklyP3SE"
data10$Period <- "WeeklyP4SE"
data11$Period <- "WeeklyP5SE"
data12$Period <- "WeeklyP6SE"
data13$Period <- "FourWeeklyP1SE"
data14$Period <- "FourWeeklyP2SE"
data15$Period <- "FourWeeklyP3SE"
data16$Period <- "FourWeeklyP4SE"
data17$Period <- "FourWeeklyP5SE"
data18$Period <- "FourWeeklyP6SE"

data_all = list(data1,data2,data3,data4,data5,data6,data7,data8,data9,data10,data11,data12,data13,data14,data15,data16,data17,data18)
SEResults <- bind_rows(data_all)
SEResults <- data.table(SEResults)

#Final table

TableSE <- as.data.table(matrix(nrow = 3, ncol=5))
colnames(TableSE) <- c("Period","2007-12","2012-17","2017-20","Average")

TableSE[,Period := as.character(Period)]

TableSE[1,"Period"] <- "Weekly"  
TableSE[2,"Period"] <- "Fourweekly"  
TableSE[3,"Period"] <- "Average"

TableSE[,`2007-12` := as.numeric(`2007-12`)]
TableSE[,`2012-17` := as.numeric(`2012-17`)]
TableSE[,`2017-20` := as.numeric(`2017-20`)]
TableSE[,`Average` := as.numeric(`Average`)]    

TableSE[1,"2007-12"] <- SEResults$StandardError[SEResults$Period == "WeeklyP1SE"]
TableSE[2,"2007-12"] <- SEResults$StandardError[SEResults$Period == "FourWeeklyP1SE"]
TableSE[1,"2012-17"] <- SEResults$StandardError[SEResults$Period == "WeeklyP2SE"]
TableSE[2,"2012-17"] <- SEResults$StandardError[SEResults$Period == "FourWeeklyP2SE"]
TableSE[1,"2017-20"] <- SEResults$StandardError[SEResults$Period == "WeeklyP4SE"]
TableSE[2,"2017-20"] <- SEResults$StandardError[SEResults$Period == "FourWeeklyP4SE"]

TableSE[1,"Average"] <- TableSE[1,`2007-12`] * 1826/4533 + TableSE[1,`2012-17`] * 1826/4533 + TableSE[1,`2017-20`] * 880/4533
TableSE[2,"Average"] <- TableSE[2,`2007-12`] * 1826/4533 + TableSE[2,`2012-17`] * 1826/4533 + TableSE[2,`2017-20`] * 880/4533

TableSE[3,"2007-12"] <- (TableSE[1,"2007-12"] + TableSE[2,"2007-12"]) / 2
TableSE[3,"2012-17"] <- (TableSE[1,"2012-17"] + TableSE[2,"2012-17"]) / 2
TableSE[3,"2017-20"] <- (TableSE[1,"2017-20"] + TableSE[2,"2017-20"]) / 2
TableSE[3,"Average"] <- (TableSE[1,"Average"] + TableSE[2,"Average"]) / 2

TableSE[,'2007-12':=round(`2007-12`,2)]
TableSE[,'2012-17':=round(`2012-17`,2)]
TableSE[,'2017-20':=round(`2017-20`,2)]
TableSE[,Average:=round(Average,2)]

TableSE

###Leverage results

Summary_table_leverage <- Final[,.(Code,DailyP1L,WeeklyP1L,FourWeeklyP1L,DailyP2L,WeeklyP2L,FourWeeklyP2L,DailyP3L,WeeklyP3L,FourWeeklyP3L)]
Summary_table_leverage <- setNames(Summary_table_leverage,c("Code","2007-12 Daily","2007-12 Weekly","2007-12 Four-weekly","2012-17 Daily","2012-17 Weekly","2012-17 Four-weekly","2017-22 Daily","2017-22 Weekly","2017-22 Four-weekly"))
write.csv(Summary_table_leverage,"Airport analysis/Results/Airports_leverage.csv")

#2007-2012
L1 <- mean(c(Final$WeeklyP1L,Final$FourWeeklyP1L),na.rm=TRUE)
#2012-2017
L2 <- mean(c(Final$WeeklyP2L,Final$FourWeeklyP2L),na.rm=TRUE)
#2017-2022
L3 <- mean(c(Final$WeeklyP3L,Final$FourWeeklyP3L),na.rm=TRUE)
#2017-2020
L4 <- mean(c(Final$WeeklyP4L,Final$FourWeeklyP4L),na.rm=TRUE)
#2020-2022
L5 <- mean(c(Final$WeeklyP5L,Final$FourWeeklyP5L),na.rm=TRUE)
#2021-2022
L6 <- mean(c(Final$WeeklyP6L,Final$FourWeeklyP6L),na.rm=TRUE)


###Summary###

Asset_beta_results_summary <- list(PreCovidA,PreCovidE,PreCovid_leverage,Last_12_beta,Last_12_leverage,mean_last_two_five_beta,mean_last_two_five_leverage)
names(Asset_beta_results_summary) <- c("Pre-covid airports asset beta", "Pre-covid airports equity beta", "Pre-covid airports leverage", "2021-2022 airports asset beta", "2021-2022 airports leverage", "Last two five years airports asset beta", "Last two five years airports leverage")
Asset_beta_results_summary

Leverage_results_summary <- list(L1,L2,L3,L4,L5,L6)
names(Leverage_results_summary) <- c("Leverage 2007-2012", "Leverage 2012-2017", "Leverage 2017-2022", "Leverage 2017-2020", "Leverage 2020-2022", "Leverage 2021-2022")
Leverage_results_summary

TableSE

###Regression of asset beta on leverage (using full sample)
regression = lm(last2fiveA ~ last2fiveL, data = Final)
summary(regression)

