#This script is for extracting data from Bloomberg

#We have observed that Bloomberg periodically revises its data. 
#Our draft and final decisions were based on Bloomberg data extracted before the draft decision

#Packages not already installed will need to be installed before they can be used
#Install packages with the same names as defined in 'library("...")' and use the 'install.packages("...")' command

####Setup####

library(data.table)
library(stringr)
library(Rblpapi)
library(dplyr)
library(zoo)
library(tidyr)

blpConnect()

####Read in inputs####

Firms <- read.csv("Data/Firms.csv", header = TRUE, stringsAsFactors = FALSE, strip.white = TRUE)

EndDateRaw <- "30/09/2022"  #Format = dd/mm/yyyy
EndDate <- as.Date(EndDateRaw, format = "%d/%m/%Y")

StartDate <- EndDate - 365*21 #start date

Fields1 <- c("PX_LAST")
Fields2 <- c("NET_DEBT", "CUR_MKT_CAP", "IS_STATUTORY_TAX_RATE")

####Extract the data####

#Currency for MKTCAP and Net Debt set to USD

FirmDataList <- bdh(securities = Firms$Code, fields = Fields1, start.date =  StartDate,
                    end.date = EndDate) #the CDR is 7D option means all days are extracted

FirmData <- bind_rows(FirmDataList, .id = "Code")

FirmDataList2 <- bdh(securities = Firms$Code, fields = Fields2, start.date =  StartDate,
                     end.date = EndDate, overrides = c("EQY_FUND_CRNCY" = "USD"), options = c("CDR" = "7D")) #the CDR is 7D option means all days are extracted

FirmData2 <- bind_rows(FirmDataList2, .id = "Code")

FirmData <- left_join(FirmData,FirmData2, by = c("Code","date"))

#Get index data

RelIndex <- bdp(Firms$Code, "BETA_OVERRIDE_REL_INDEX")
Firms$RelIndex <- RelIndex$BETA_OVERRIDE_REL_INDEX

Fields <-  c("PX_LAST")

IndexDataList <- bdh(securities = Firms$RelIndex, fields = Fields, start.date =  StartDate,
                     end.date = EndDate)

names(IndexDataList)[names(IndexDataList) == ""] <- "Remove" #Error handling

IndexData <- bind_rows(IndexDataList, .id = "RelIndex")

colnames(IndexData) <- c("RelIndex", "date", "INDEX_PX_LAST")

IndexData <- distinct(IndexData, date, RelIndex, .keep_all = TRUE)

#Combine index and firm data

FirmData <- left_join(FirmData, Firms, by = "Code")
CombinedData <- left_join(FirmData, IndexData, by = c("RelIndex", "date"))

write.csv(CombinedData, "Data/FinalDataset.csv", row.names = FALSE)

###Create Energy datatset###

Firms <- read.csv("Data/Firms_Energy.csv", header = TRUE, stringsAsFactors = FALSE, strip.white = TRUE) |> #list of comparators
  mutate(Sample_2020 = Sample_2022)    # AS added to make 2-year estimate work

Firms <- data.table(Firms)

Data <- read.csv("Data/FinalDataset.csv", header = TRUE, stringsAsFactors = FALSE, strip.white = TRUE)

Data_Energy <- merge(Data, Firms[ , c("Code")], by = "Code")

write.csv(Data_Energy, "Data/FinalDataset_Energy_delisted.csv", row.names = FALSE)

###Create Airports dataset###

Firms <- read.csv("Data/Firms_Airport.csv") |> # header = TRUE, stringsAsFactors = FALSE, strip.white = TRUE) |> #list of comparators
  mutate(Sample_2020 = Sample_2022)    # AS added to make 2-year estimate work

Firms <- data.table(Firms)

Data <- read.csv("Data/FinalDataset.csv", header = TRUE, stringsAsFactors = FALSE, strip.white = TRUE)

Data_Airports <- merge(Data, Firms[ , c("Code")], by = "Code")

write.csv(Data_Airports, "Data/FinalDataset_Airports_delisted.csv", row.names = FALSE)
