#Vector master

#This script runs all the functions in linear order

####Setup####

library(stringr)
library(Rblpapi)
library(dplyr)
library(zoo)
library(tidyr)
library(janitor) 
library(lubridate) 
library(data.table)

#Inputs

Firms <- read.csv("Data/Firms_Energy.csv", header = TRUE, stringsAsFactors = FALSE, strip.white = TRUE) |> #list of comparators
  mutate(Sample_2020 = Sample_2022)    # AS added to make 2-year estimate work

#Restrict the sample to Vector only
Firms <- data.table(Firms)
Firms <- Firms[Code == "VCT NZ Equity"]

#Loop through the different time periods

source("Energy analysis - Vector/Estimate_daily.R")
source("Energy analysis - Vector/Estimate_weekly.R")
source("Energy analysis - Vector/Estimate_fourWeekly.R")

DateEnds <- list("30/09/2012","30/09/2017","30/09/2022","28/02/2020","30/09/2022", "30/09/2022")
DateStarts <- list("01/10/2007","01/10/2012","01/10/2017","01/10/2017","01/03/2020", "01/10/2021")

 for (j in 1:6) {
   EndDate <- dmy(DateEnds[j])
   StartDate <- dmy(DateStarts[j])
   Sample <- format(EndDate, format = "%Y")

    EstimateDaily(EndDate,StartDate,Sample,Firms)
    EstimateWeekly(EndDate,StartDate,Sample,Firms)
    EstimateFourWeekly(EndDate,StartDate,Sample,Firms)
}

#Analyse results

#Read in weekly data
DateEnds <- list("2012-09-30","2017-09-30","2022-09-30","2020-02-28","2022-09-30", "2022-09-30") 
DateStarts <- list("2007-10-01","2012-10-01","2017-10-01","2017-10-01","2020-03-01","2021-10-01")


text_location <- "Energy analysis - Vector/Results/"

data1 <- fread(paste(text_location,"StartDate-",DateStarts[1],"EndDate-",DateEnds[1],"-Daily-Results.csv",sep=""))
data2 <- fread(paste(text_location,"StartDate-",DateStarts[2],"EndDate-",DateEnds[2],"-Daily-Results.csv",sep=""))
data3 <- fread(paste(text_location,"StartDate-",DateStarts[3],"EndDate-",DateEnds[3],"-Daily-Results.csv",sep=""))
data4 <- fread(paste(text_location,"StartDate-",DateStarts[4],"EndDate-",DateEnds[4],"-Daily-Results.csv",sep=""))
data5 <- fread(paste(text_location,"StartDate-",DateStarts[5],"EndDate-",DateEnds[5],"-Daily-Results.csv",sep=""))
data6 <- fread(paste(text_location,"StartDate-",DateStarts[6],"EndDate-",DateEnds[6],"-Daily-Results.csv",sep=""))


data7 <- fread(paste(text_location,"StartDate-",DateStarts[1],"EndDate-",DateEnds[1],"-Weekly-Results.csv",sep=""))
data8 <- fread(paste(text_location,"StartDate-",DateStarts[2],"EndDate-",DateEnds[2],"-Weekly-Results.csv",sep=""))
data9 <- fread(paste(text_location,"StartDate-",DateStarts[3],"EndDate-",DateEnds[3],"-Weekly-Results.csv",sep=""))
data10 <- fread(paste(text_location,"StartDate-",DateStarts[4],"EndDate-",DateEnds[4],"-Weekly-Results.csv",sep=""))
data11 <- fread(paste(text_location,"StartDate-",DateStarts[5],"EndDate-",DateEnds[5],"-Weekly-Results.csv",sep=""))
data12 <- fread(paste(text_location,"StartDate-",DateStarts[6],"EndDate-",DateEnds[6],"-Weekly-Results.csv",sep=""))


data13 <- fread(paste(text_location,"StartDate-",DateStarts[1],"EndDate-",DateEnds[1],"-FourWeekly-Results.csv",sep=""))
data14 <- fread(paste(text_location,"StartDate-",DateStarts[2],"EndDate-",DateEnds[2],"-FourWeekly-Results.csv",sep=""))
data15 <- fread(paste(text_location,"StartDate-",DateStarts[3],"EndDate-",DateEnds[3],"-FourWeekly-Results.csv",sep=""))
data16 <- fread(paste(text_location,"StartDate-",DateStarts[4],"EndDate-",DateEnds[4],"-FourWeekly-Results.csv",sep=""))
data17 <- fread(paste(text_location,"StartDate-",DateStarts[5],"EndDate-",DateEnds[5],"-FourWeekly-Results.csv",sep=""))
data18 <- fread(paste(text_location,"StartDate-",DateStarts[6],"EndDate-",DateEnds[6],"-FourWeekly-Results.csv",sep=""))

data1 <- data1[,c(1,5,7)]
data2 <- data2[,c(1,5,7)]
data3 <- data3[,c(1,5,7)]
data4 <- data4[,c(1,5,7)]
data5 <- data5[,c(1,5,7)]
data6 <- data6[,c(1,5,7)]
data7 <- data7[,c(1,2,3)]
data8 <- data8[,c(1,2,3)]
data9 <- data9[,c(1,2,3)]
data10 <- data10[,c(1,2,3)]
data11 <- data11[,c(1,2,3)]
data12 <- data12[,c(1,2,3)]
data13 <- data13[,c(1,2,3)]
data14 <- data14[,c(1,2,3)]
data15 <- data15[,c(1,2,3)]
data16 <- data16[,c(1,2,3)]
data17 <- data17[,c(1,2,3)]
data18 <- data18[,c(1,2,3)]


setnames(data1,"Assetbeta","DailyP1A")
setnames(data2,"Assetbeta","DailyP2A")
setnames(data3,"Assetbeta","DailyP3A")
setnames(data4,"Assetbeta","DailyP4A")
setnames(data5,"Assetbeta","DailyP5A")
setnames(data6,"Assetbeta","DailyP6A")
setnames(data7,"Assetbeta","WeeklyP1A")
setnames(data8,"Assetbeta","WeeklyP2A")
setnames(data9,"Assetbeta","WeeklyP3A")
setnames(data10,"Assetbeta","WeeklyP4A")
setnames(data11,"Assetbeta","WeeklyP5A")
setnames(data12,"Assetbeta","WeeklyP6A")
setnames(data13,"Assetbeta","FourWeeklyP1A")
setnames(data14,"Assetbeta","FourWeeklyP2A")
setnames(data15,"Assetbeta","FourWeeklyP3A")
setnames(data16,"Assetbeta","FourWeeklyP4A")
setnames(data17,"Assetbeta","FourWeeklyP5A")
setnames(data18,"Assetbeta","FourWeeklyP6A")

setnames(data1,"AverageGearingDV","DailyP1L")
setnames(data2,"AverageGearingDV","DailyP2L")
setnames(data3,"AverageGearingDV","DailyP3L")
setnames(data4,"AverageGearingDV","DailyP4L")
setnames(data5,"AverageGearingDV","DailyP5L")
setnames(data6,"AverageGearingDV","DailyP6L")
setnames(data7,"gearingDV","WeeklyP1L")
setnames(data8,"gearingDV","WeeklyP2L")
setnames(data9,"gearingDV","WeeklyP3L")
setnames(data10,"gearingDV","WeeklyP4L")
setnames(data11,"gearingDV","WeeklyP5L")
setnames(data12,"gearingDV","WeeklyP6L")
setnames(data13,"gearingDV","FourWeeklyP1L")
setnames(data14,"gearingDV","FourWeeklyP2L")
setnames(data15,"gearingDV","FourWeeklyP3L")
setnames(data16,"gearingDV","FourWeeklyP4L")
setnames(data17,"gearingDV","FourWeeklyP5L")
setnames(data18,"gearingDV","FourWeeklyP6L")

setkey(data1, Code)
setkey(data2, Code)
setkey(data3, Code)
setkey(data4, Code)
setkey(data5, Code)
setkey(data6, Code)
setkey(data7, Code)
setkey(data8, Code)
setkey(data9, Code)
setkey(data10, Code)
setkey(data11, Code)
setkey(data12, Code)
setkey(data13, Code)
setkey(data14, Code)
setkey(data15, Code)
setkey(data16, Code)
setkey(data17, Code)
setkey(data18, Code)

data_all = list(data1,data2,data3,data4,data5,data6,data7,data8,data9,data10,data11,data12,data13,data14,data15,data16,data17,data18)
Results <- purrr::reduce(data_all,dplyr::full_join,by="Code")

#Add back equity betas
Results$DailyP1E <- Results$DailyP1A / (1-Results$DailyP1L)
Results$DailyP2E <- Results$DailyP2A / (1-Results$DailyP2L)
Results$DailyP3E <- Results$DailyP3A / (1-Results$DailyP3L)
Results$DailyP4E <- Results$DailyP4A / (1-Results$DailyP4L)
Results$DailyP5E <- Results$DailyP5A / (1-Results$DailyP5L)
Results$DailyP6E <- Results$DailyP6A / (1-Results$DailyP6L)

Results$WeeklyP1E <- Results$WeeklyP1A / (1-Results$WeeklyP1L)
Results$WeeklyP2E <- Results$WeeklyP2A / (1-Results$WeeklyP2L)
Results$WeeklyP3E <- Results$WeeklyP3A / (1-Results$WeeklyP3L)
Results$WeeklyP4E <- Results$WeeklyP4A / (1-Results$WeeklyP4L)
Results$WeeklyP5E <- Results$WeeklyP5A / (1-Results$WeeklyP5L)
Results$WeeklyP6E <- Results$WeeklyP6A / (1-Results$WeeklyP6L)

Results$FourWeeklyP1E <- Results$FourWeeklyP1A / (1-Results$FourWeeklyP1L)
Results$FourWeeklyP2E <- Results$FourWeeklyP2A / (1-Results$FourWeeklyP2L)
Results$FourWeeklyP3E <- Results$FourWeeklyP3A / (1-Results$FourWeeklyP3L)
Results$FourWeeklyP4E <- Results$FourWeeklyP4A / (1-Results$FourWeeklyP4L)
Results$FourWeeklyP5E <- Results$FourWeeklyP5A / (1-Results$FourWeeklyP5L)
Results$FourWeeklyP6E <- Results$FourWeeklyP6A / (1-Results$FourWeeklyP6L)

#Calculate pre-covid leverage
Results <- Results[, PreCovid1L := mean(c(WeeklyP1L,FourWeeklyP1L),na.rm=TRUE), by=Code]
Results <- Results[, PreCovid2L := mean(c(WeeklyP2L,FourWeeklyP2L),na.rm=TRUE), by=Code]
Results <- Results[, PreCovid3L := mean(c(WeeklyP4L,FourWeeklyP4L),na.rm=TRUE), by=Code]

Results[,PreCovidL := PreCovid1L * 1826/4533 + PreCovid2L * 1826/4533 + PreCovid3L * 880/4533]

#Calculate the pre-Covid asset beta
Results <- Results[, PreCovid1A := mean(c(WeeklyP1A,FourWeeklyP1A),na.rm=TRUE), by=Code]
Results <- Results[, PreCovid2A := mean(c(WeeklyP2A,FourWeeklyP2A),na.rm=TRUE), by=Code]
Results <- Results[, PreCovid3A := mean(c(WeeklyP4A,FourWeeklyP4A),na.rm=TRUE), by=Code]

Results[,PreCovidA := PreCovid1A * 1826/4533 + PreCovid2A * 1826/4533 + PreCovid3A * 880/4533]

Summary <- Results[,.(Code,PreCovidA)]
PreCovid_beta <- mean(Results$PreCovidA, na.rm=TRUE)
PreCovid_beta

#Calculate the asset beta for the period 1 October 2017 to 30 September 2022

PreCovid3A_beta <-mean(Results$PreCovid3A, na.rm=TRUE)
PreCovid3A_beta

#Calculate the asset beta for the period 1 March 2020 to 30 September 2022

Results <- Results[, PreCovid5A := mean(c(WeeklyP5A,FourWeeklyP5A),na.rm=TRUE), by=Code]
PreCovid5A_beta <-mean(Results$PreCovid5A, na.rm=TRUE)
PreCovid5A_beta

#Calculate the pre-Covid equity beta
Results$PreCovid1E <- (Results$WeeklyP1E + Results$FourWeeklyP1E) / 2
Results$PreCovid2E <- (Results$WeeklyP2E + Results$FourWeeklyP2E) / 2
Results$PreCovid3E <- (Results$WeeklyP3E + Results$FourWeeklyP3E) / 2

Results[,PreCovidE := PreCovid1E * 1826/4533 + PreCovid2E * 1826/4533 + PreCovid3E * 880/4533]

PreCovid_betaE <- mean(Results$PreCovidE, na.rm=TRUE)
PreCovid_betaE

#Calculate the pre-Covid leverage
Summary <- Results[,.(Code,PreCovidA,PreCovidL)]
PreCovid_leverage <- mean(Results$PreCovidL, na.rm=TRUE)
PreCovid_leverage

#Calculate the last 12 months asset beta and leverage
Results <- Results[, Last12A := mean(c(WeeklyP6A,FourWeeklyP6A),na.rm=TRUE), by=Code]
Results <- Results[, Last12L := mean(c(WeeklyP6L,FourWeeklyP6L),na.rm=TRUE), by=Code]
Last_12_beta <- mean(Results$Last12A, na.rm=TRUE)
Last_12_leverage <- mean(Results$Last12L, na.rm=TRUE)
Last_12_beta
Last_12_leverage

Summary <- Results[,.(Code,Last12A,Last12L)]

#Calculate the last two 5-years asset beta and leverage
Results <- Results[, last2fiveA := mean(c(WeeklyP2A,FourWeeklyP2A,WeeklyP3A,FourWeeklyP3A),na.rm=TRUE), by=Code]
Results <- Results[, last2fiveL := mean(c(WeeklyP2L,FourWeeklyP2L,WeeklyP3L,FourWeeklyP3L),na.rm=TRUE), by=Code]

mean_last_two_five_beta <- mean(Results$last2fiveA)
mean_last_two_five_leverage <- mean(Results$last2fiveL)
mean_last_two_five_beta
mean_last_two_five_leverage

Summary <- Results[,.(Code,last2fiveA,last2fiveL)]


#Prepare tables for publication
Summary_table_betas <- Results[,.(Code,DailyP1A,WeeklyP1A,FourWeeklyP1A,DailyP2A,WeeklyP2A,FourWeeklyP2A,DailyP3A,WeeklyP3A,FourWeeklyP3A)]

Summary_table_betas <- setNames(Summary_table_betas,c("Code","2007-12 Daily","2007-12 Weekly","2007-12 Four-weekly","2012-17 Daily","2012-17 Weekly","2012-17 Four-weekly","2017-22 Daily","2017-22 Weekly","2017-22 Four-weekly"))
write.csv(Summary_table_betas,"Energy analysis - Vector/Results/Energy_betas.csv")

Summary_table_betas <- Results[,.(Code,DailyP1A,WeeklyP1A,FourWeeklyP1A,DailyP2A,WeeklyP2A,FourWeeklyP2A,DailyP3A,WeeklyP3A,FourWeeklyP3A)]

Summary_table_betas <- setNames(Summary_table_betas,c("Firm","2007-12 Daily","2007-12 Weekly","2007-12 Four-weekly","2012-17 Daily","2012-17 Weekly","2012-17 Four-weekly","2017-22 Daily","2017-22 Weekly","2017-22 Four-weekly"))

Summary_table_betas$out <- ifelse (Summary_table_betas$Firm %in% c("AGR US Equity","CPK US Equity","MGEE US Equity","NWN US Equity","RGCO US Equity","UTL US Equity","SKI AU Equity","OKE US Equity"),1,0)
setkey(Summary_table_betas,out)

write.csv(Summary_table_betas,"Energy analysis - Vector/Results/Energy_betas.csv")

Summary_table_leverage <- Results[,.(Code,DailyP1L,WeeklyP1L,FourWeeklyP1L,DailyP2L,WeeklyP2L,FourWeeklyP2L,DailyP3L,WeeklyP3L,FourWeeklyP3L)]

Summary_table_leverage <- setNames(Summary_table_leverage,c("Code","2007-12 Daily","2007-12 Weekly","2007-12 Four-weekly","2012-17 Daily","2012-17 Weekly","2012-17 Four-weekly","2017-22 Daily","2017-22 Weekly","2017-22 Four-weekly"))
write.csv(Summary_table_leverage,"Energy analysis - Vector/Results/Energy_leverage.csv")

Summary_table_leverage <- Results[,.(Code,DailyP1L,WeeklyP1L,FourWeeklyP1L,DailyP2L,WeeklyP2L,FourWeeklyP2L,DailyP3L,WeeklyP3L,FourWeeklyP3L)]

Summary_table_leverage <- setNames(Summary_table_leverage,c("Firm","2007-12 Daily","2007-12 Weekly","2007-12 Four-weekly","2012-17 Daily","2012-17 Weekly","2012-17 Four-weekly","2017-22 Daily","2017-22 Weekly","2017-22 Four-weekly"))

Summary_table_leverage$out <- ifelse (Summary_table_leverage$Firm %in% c("AGR US Equity","CPK US Equity","MGEE US Equity","NWN US Equity","RGCO US Equity","UTL US Equity","SKI AU Equity","OKE US Equity"),1,0)
setkey(Summary_table_leverage,out)

write.csv(Summary_table_leverage,"Energy analysis - Vector/Results/Energy_leverage.csv")

#Standard error analysis#

#Read in weekly data
DateEnds <- list("2012-09-30","2017-09-30","2022-09-30","2020-02-28","2022-09-30", "2022-09-30") 
DateStarts <- list("2007-10-01","2012-10-01","2017-10-01","2017-10-01","2020-03-01","2021-10-01")

text_location <- "Energy analysis - Vector/Results/"

data1 <- fread(paste(text_location,"StartDate-",DateStarts[1],"EndDate-",DateEnds[1],"-Daily-StandardErrorResults.csv",sep=""))
data2 <- fread(paste(text_location,"StartDate-",DateStarts[2],"EndDate-",DateEnds[2],"-Daily-StandardErrorResults.csv",sep=""))
data3 <- fread(paste(text_location,"StartDate-",DateStarts[3],"EndDate-",DateEnds[3],"-Daily-StandardErrorResults.csv",sep=""))
data4 <- fread(paste(text_location,"StartDate-",DateStarts[4],"EndDate-",DateEnds[4],"-Daily-StandardErrorResults.csv",sep=""))
data5 <- fread(paste(text_location,"StartDate-",DateStarts[5],"EndDate-",DateEnds[5],"-Daily-StandardErrorResults.csv",sep=""))
data6 <- fread(paste(text_location,"StartDate-",DateStarts[6],"EndDate-",DateEnds[6],"-Daily-StandardErrorResults.csv",sep=""))

data7 <- fread(paste(text_location,"StartDate-",DateStarts[1],"EndDate-",DateEnds[1],"-Weekly-StandardErrorResults.csv",sep=""))
data8 <- fread(paste(text_location,"StartDate-",DateStarts[2],"EndDate-",DateEnds[2],"-Weekly-StandardErrorResults.csv",sep=""))
data9 <- fread(paste(text_location,"StartDate-",DateStarts[3],"EndDate-",DateEnds[3],"-Weekly-StandardErrorResults.csv",sep=""))
data10 <- fread(paste(text_location,"StartDate-",DateStarts[4],"EndDate-",DateEnds[4],"-Weekly-StandardErrorResults.csv",sep=""))
data11 <- fread(paste(text_location,"StartDate-",DateStarts[5],"EndDate-",DateEnds[5],"-Weekly-StandardErrorResults.csv",sep=""))
data12 <- fread(paste(text_location,"StartDate-",DateStarts[6],"EndDate-",DateEnds[6],"-Weekly-StandardErrorResults.csv",sep=""))

data13 <- fread(paste(text_location,"StartDate-",DateStarts[1],"EndDate-",DateEnds[1],"-FourWeekly-StandardErrorResults.csv",sep=""))
data14 <- fread(paste(text_location,"StartDate-",DateStarts[2],"EndDate-",DateEnds[2],"-FourWeekly-StandardErrorResults.csv",sep=""))
data15 <- fread(paste(text_location,"StartDate-",DateStarts[3],"EndDate-",DateEnds[3],"-FourWeekly-StandardErrorResults.csv",sep=""))
data16 <- fread(paste(text_location,"StartDate-",DateStarts[4],"EndDate-",DateEnds[4],"-FourWeekly-StandardErrorResults.csv",sep=""))
data17 <- fread(paste(text_location,"StartDate-",DateStarts[5],"EndDate-",DateEnds[5],"-FourWeekly-StandardErrorResults.csv",sep=""))
data18 <- fread(paste(text_location,"StartDate-",DateStarts[6],"EndDate-",DateEnds[6],"-FourWeekly-StandardErrorResults.csv",sep=""))

data1$Period <- "DailyP1SE"
data2$Period <- "DailyP2SE"
data3$Period <- "DailyP3SE"
data4$Period <- "DailyP4SE"
data5$Period <- "DailyP5SE"
data6$Period <- "DailyP6SE"
data7$Period <- "WeeklyP1SE"
data8$Period <- "WeeklyP2SE"
data9$Period <- "WeeklyP3SE"
data10$Period <- "WeeklyP4SE"
data11$Period <- "WeeklyP5SE"
data12$Period <- "WeeklyP6SE"
data13$Period <- "FourWeeklyP1SE"
data14$Period <- "FourWeeklyP2SE"
data15$Period <- "FourWeeklyP3SE"
data16$Period <- "FourWeeklyP4SE"
data17$Period <- "FourWeeklyP5SE"
data18$Period <- "FourWeeklyP6SE"

data_all = list(data1,data2,data3,data4,data5,data6,data7,data8,data9,data10,data11,data12,data13,data14,data15,data16,data17,data18)
SEResults <- bind_rows(data_all)
SEResults <- data.table(SEResults)

#Final table

#TableSE2 <- as.data.table(matrix(nrow = 3, ncol=4))
#colnames(TableSE2) <- c("Period","2012-17","2017-22","Average")

#TableSE2[,Period := as.character(Period)]

#TableSE2[1,"Period"] <- "Weekly"  
#TableSE2[2,"Period"] <- "Fourweekly"  
#TableSE2[3,"Period"] <- "Average"

#TableSE2[,`2012-17` := as.numeric(`2012-17`)]
#TableSE2[,`2017-22` := as.numeric(`2017-22`)]
#TableSE2[,`Average` := as.numeric(`Average`)]    

#TableSE2[1,"2012-17"] <- SEResults$StandardError[SEResults$Period == "WeeklyP2SE"]
#TableSE2[2,"2012-17"] <- SEResults$StandardError[SEResults$Period == "FourWeeklyP2SE"]
#TableSE2[1,"2017-22"] <- SEResults$StandardError[SEResults$Period == "WeeklyP3SE"]
#TableSE2[2,"2017-22"] <- SEResults$StandardError[SEResults$Period == "FourWeeklyP3SE"]

#TableSE2[1,"Average"] <- (TableSE2[1,`2012-17`]  + TableSE2[1,`2017-22`]) /2
#TableSE2[2,"Average"] <- (TableSE2[2,`2012-17`]  + TableSE2[2,`2017-22`]) /2

#TableSE2[3,"2012-17"] <- (TableSE2[1,"2012-17"] + TableSE2[2,"2012-17"]) / 2
#TableSE2[3,"2017-22"] <- (TableSE2[1,"2017-22"] + TableSE2[2,"2017-22"]) / 2
#TableSE2[3,"Average"] <- (TableSE2[1,"Average"] + TableSE2[2,"Average"]) / 2

#TableSE2[,'2012-17':=round(`2012-17`,2)]
#TableSE2[,'2017-22':=round(`2017-22`,2)]
#TableSE2[,Average:=round(Average,2)]


# Standard error of individual company ------------------------------------

#Read in data
DateEnds <- list("2012-09-30","2017-09-30","2022-09-30","2020-02-28","2022-09-30", "2022-09-30") 
DateStarts <- list("2007-10-01","2012-10-01","2017-10-01","2017-10-01","2020-03-01","2021-10-01")

text_location <- "Energy analysis - Vector/Results/"

data1 <- fread(paste(text_location,"StartDate-",DateStarts[1],"EndDate-",DateEnds[1],"-Daily-Results.csv",sep=""))
data2 <- fread(paste(text_location,"StartDate-",DateStarts[2],"EndDate-",DateEnds[2],"-Daily-Results.csv",sep=""))
data3 <- fread(paste(text_location,"StartDate-",DateStarts[3],"EndDate-",DateEnds[3],"-Daily-Results.csv",sep=""))
data4 <- fread(paste(text_location,"StartDate-",DateStarts[4],"EndDate-",DateEnds[4],"-Daily-Results.csv",sep=""))
data5 <- fread(paste(text_location,"StartDate-",DateStarts[5],"EndDate-",DateEnds[5],"-Daily-Results.csv",sep=""))
data6 <- fread(paste(text_location,"StartDate-",DateStarts[6],"EndDate-",DateEnds[6],"-Daily-Results.csv",sep=""))
data7 <- fread(paste(text_location,"StartDate-",DateStarts[1],"EndDate-",DateEnds[1],"-Weekly-Results.csv",sep=""))
data8 <- fread(paste(text_location,"StartDate-",DateStarts[2],"EndDate-",DateEnds[2],"-Weekly-Results.csv",sep=""))
data9 <- fread(paste(text_location,"StartDate-",DateStarts[3],"EndDate-",DateEnds[3],"-Weekly-Results.csv",sep=""))
data10 <- fread(paste(text_location,"StartDate-",DateStarts[4],"EndDate-",DateEnds[4],"-Weekly-Results.csv",sep=""))
data11 <- fread(paste(text_location,"StartDate-",DateStarts[5],"EndDate-",DateEnds[5],"-Weekly-Results.csv",sep=""))
data12 <- fread(paste(text_location,"StartDate-",DateStarts[6],"EndDate-",DateEnds[6],"-Weekly-Results.csv",sep=""))
data13 <- fread(paste(text_location,"StartDate-",DateStarts[1],"EndDate-",DateEnds[1],"-FourWeekly-Results.csv",sep=""))
data14 <- fread(paste(text_location,"StartDate-",DateStarts[2],"EndDate-",DateEnds[2],"-FourWeekly-Results.csv",sep=""))
data15 <- fread(paste(text_location,"StartDate-",DateStarts[3],"EndDate-",DateEnds[3],"-FourWeekly-Results.csv",sep=""))
data16 <- fread(paste(text_location,"StartDate-",DateStarts[4],"EndDate-",DateEnds[4],"-FourWeekly-Results.csv",sep=""))
data17 <- fread(paste(text_location,"StartDate-",DateStarts[5],"EndDate-",DateEnds[5],"-FourWeekly-Results.csv",sep=""))
data18 <- fread(paste(text_location,"StartDate-",DateStarts[6],"EndDate-",DateEnds[6],"-FourWeekly-Results.csv",sep=""))

data1 <- data1[,c(1,7,8)]
data2 <- data2[,c(1,7,8)]
data3 <- data3[,c(1,7,8)]
data4 <- data4[,c(1,7,8)]
data5 <- data5[,c(1,7,8)]
data6 <- data6[,c(1,7,8)]
data7 <- data7[,c(1,2,4)]
data8 <- data8[,c(1,2,4)]
data9 <- data9[,c(1,2,4)]
data10 <- data10[,c(1,2,4)]
data11 <- data11[,c(1,2,4)]
data12 <- data12[,c(1,2,4)]
data13 <- data13[,c(1,2,4)]
data14 <- data14[,c(1,2,4)]
data15 <- data15[,c(1,2,4)]
data16 <- data16[,c(1,2,4)]
data17 <- data17[,c(1,2,4)]
data18 <- data18[,c(1,2,4)]

data1 <- data1 %>% mutate(period=paste("StartDate-",DateStarts[1],"EndDate-",DateEnds[1],"-Daily"))
data2 <- data2 %>% mutate(period=paste("StartDate-",DateStarts[2],"EndDate-",DateEnds[2],"-Daily"))
data3 <- data3 %>% mutate(period=paste("StartDate-",DateStarts[3],"EndDate-",DateEnds[3],"-Daily"))
data4 <- data4 %>% mutate(period=paste("StartDate-",DateStarts[4],"EndDate-",DateEnds[4],"-Daily"))
data5 <- data5 %>% mutate(period=paste("StartDate-",DateStarts[5],"EndDate-",DateEnds[5],"-Daily"))
data6 <- data6 %>% mutate(period=paste("StartDate-",DateStarts[6],"EndDate-",DateEnds[6],"-Daily"))
data7 <- data7 %>% mutate(period=paste("StartDate-",DateStarts[1],"EndDate-",DateEnds[1],"-Weekly"))
data8 <- data8 %>% mutate(period=paste("StartDate-",DateStarts[2],"EndDate-",DateEnds[2],"-Weekly"))
data9 <- data9 %>% mutate(period=paste("StartDate-",DateStarts[3],"EndDate-",DateEnds[3],"-Weeky"))
data10 <- data10 %>% mutate(period=paste("StartDate-",DateStarts[4],"EndDate-",DateEnds[4],"-Weekly"))
data11 <- data11 %>% mutate(period=paste("StartDate-",DateStarts[5],"EndDate-",DateEnds[5],"-Weekly"))
data12 <- data12 %>% mutate(period=paste("StartDate-",DateStarts[6],"EndDate-",DateEnds[6],"-Weekly"))
data13 <- data13 %>% mutate(period=paste("StartDate-",DateStarts[1],"EndDate-",DateEnds[1],"-Four_Weekly"))
data14 <- data14 %>% mutate(period=paste("StartDate-",DateStarts[2],"EndDate-",DateEnds[2],"-Four_Weekly"))
data15 <- data15 %>% mutate(period=paste("StartDate-",DateStarts[3],"EndDate-",DateEnds[3],"-Four_Weekly"))
data16 <- data16 %>% mutate(period=paste("StartDate-",DateStarts[4],"EndDate-",DateEnds[4],"-Four_Weekly"))
data17 <- data17 %>% mutate(period=paste("StartDate-",DateStarts[5],"EndDate-",DateEnds[5],"-Four_Weekly"))
data18 <- data18 %>% mutate(period=paste("StartDate-",DateStarts[6],"EndDate-",DateEnds[6],"-Four_Weekly"))

setkey(data1, Code)
setkey(data2, Code)
setkey(data3, Code)
setkey(data4, Code)
setkey(data5, Code)
setkey(data6, Code)
setkey(data7, Code)
setkey(data8, Code)
setkey(data9, Code)
setkey(data10, Code)
setkey(data11, Code)
setkey(data12, Code)
setkey(data13, Code)
setkey(data14, Code)
setkey(data15, Code)
setkey(data16, Code)
setkey(data17, Code)
setkey(data18, Code)

data_all = list(data1,data2,data3,data4,data5,data6,data7,data8,data9,data10,data11,data12,data13,data14,data15,data16,data17,data18)
SE_individual_Results <- bind_rows(data_all)
SE_individual_Results <- data.table(SE_individual_Results)

SE_individual_Results

###Individual standard error - used to calculate Vector standard error###

Table_individual_SE <- as.data.table(matrix(nrow = 3, ncol=5))
colnames(Table_individual_SE) <- c("Period","2007-12","2012-17","2017-20","Average")

Table_individual_SE[,Period := as.character(Period)]

Table_individual_SE[1,"Period"] <- "Weekly"  
Table_individual_SE[2,"Period"] <- "Fourweekly"  
Table_individual_SE[3,"Period"] <- "Average"

Table_individual_SE[,`2007-12` := as.numeric(`2007-12`)]
Table_individual_SE[,`2012-17` := as.numeric(`2012-17`)]
Table_individual_SE[,`2017-20` := as.numeric(`2017-20`)]
Table_individual_SE[,`Average` := as.numeric(`Average`)]    

Table_individual_SE[1,"2007-12"] <- SE_individual_Results$SE_AssetBeta[SE_individual_Results$period == "StartDate- 2007-10-01 EndDate- 2012-09-30 -Weekly"]
Table_individual_SE[2,"2007-12"] <- SE_individual_Results$SE_AssetBeta[SE_individual_Results$period == "StartDate- 2007-10-01 EndDate- 2012-09-30 -Four_Weekly"]
Table_individual_SE[1,"2012-17"] <- SE_individual_Results$SE_AssetBeta[SE_individual_Results$period == "StartDate- 2012-10-01 EndDate- 2017-09-30 -Weekly"]
Table_individual_SE[2,"2012-17"] <- SE_individual_Results$SE_AssetBeta[SE_individual_Results$period == "StartDate- 2012-10-01 EndDate- 2017-09-30 -Four_Weekly"]
Table_individual_SE[1,"2017-20"] <- SE_individual_Results$SE_AssetBeta[SE_individual_Results$period == "StartDate- 2017-10-01 EndDate- 2020-02-28 -Weekly"]
Table_individual_SE[2,"2017-20"] <- SE_individual_Results$SE_AssetBeta[SE_individual_Results$period == "StartDate- 2017-10-01 EndDate- 2020-02-28 -Four_Weekly"]

Table_individual_SE[1,"Average"] <- Table_individual_SE[1,`2007-12`] * 1826/4533 + Table_individual_SE[1,`2012-17`] * 1826/4533 + Table_individual_SE[1,`2017-20`] * 880/4533
Table_individual_SE[2,"Average"] <- Table_individual_SE[2,`2007-12`] * 1826/4533 + Table_individual_SE[2,`2012-17`] * 1826/4533 + Table_individual_SE[2,`2017-20`] * 880/4533

Table_individual_SE[3,"2007-12"] <- (Table_individual_SE[1,"2007-12"] + Table_individual_SE[2,"2007-12"]) / 2
Table_individual_SE[3,"2012-17"] <- (Table_individual_SE[1,"2012-17"] + Table_individual_SE[2,"2012-17"]) / 2
Table_individual_SE[3,"2017-20"] <- (Table_individual_SE[1,"2017-20"] + Table_individual_SE[2,"2017-20"]) / 2
Table_individual_SE[3,"Average"] <- (Table_individual_SE[1,"Average"] + Table_individual_SE[2,"Average"]) / 2

Table_individual_SE[,'2007-12':=round(`2007-12`,2)]
Table_individual_SE[,'2012-17':=round(`2012-17`,2)]
Table_individual_SE[,'2017-20':=round(`2017-20`,2)]
Table_individual_SE[,Average:=round(Average,2)]

Table_individual_SE

###Leverage results

#2007-2012
L1 <- mean(c(Results$WeeklyP1L,Results$FourWeeklyP1L),na.rm=TRUE)
#2012-2017
L2 <- mean(c(Results$WeeklyP2L,Results$FourWeeklyP2L),na.rm=TRUE)
#2017-2022
L3 <- mean(c(Results$WeeklyP3L,Results$FourWeeklyP3L),na.rm=TRUE)
#2017-2020
L4 <- mean(c(Results$WeeklyP4L,Results$FourWeeklyP4L),na.rm=TRUE)
#2020-2022
L5 <- mean(c(Results$WeeklyP5L,Results$FourWeeklyP5L),na.rm=TRUE)
#2021-2022
L6 <- mean(c(Results$WeeklyP6L,Results$FourWeeklyP6L),na.rm=TRUE)

###Summary of energy results###

Asset_beta_results_summary <- list(PreCovid_beta,PreCovid_betaE,PreCovid_leverage,Last_12_beta,Last_12_leverage,mean_last_two_five_beta,mean_last_two_five_leverage)
names(Asset_beta_results_summary) <- c("Pre-covid energy asset beta", "Pre-covid energy equity beta", "Pre-covid energy leverage", "2021-2022 energy asset beta", "2021-2022 energy leverage", "Last two five years energy asset beta", "Last two five years energy leverage")
Asset_beta_results_summary

Leverage_results_summary <- list(L1,L2,L3,L4,L5,L6)
names(Leverage_results_summary) <- c("Leverage 2007-2012", "Leverage 2012-2017", "Leverage 2017-2022", "Leverage 2017-2020", "Leverage 2020-2022", "Leverage 2021-2022")
Leverage_results_summary

#Standard error summary
Table_individual_SE

