#Flint analysis method - Energy sample

#This script runs all the functions in linear order

####Setup####

library(stringr)
library(Rblpapi)
library(dplyr)
library(zoo)
library(tidyr)
library(janitor)
library(lubridate)
library(data.table)

Firms <- read.csv("Data/Firms_Energy.csv", header = TRUE, stringsAsFactors = FALSE, strip.white = TRUE) |> #list of comparators
  mutate(Sample_2020 = Sample_2022)

# Restrict to Vector or final Energy sample
Firms <- data.table(Firms)
Firms <- Firms[!(Code %in% c("AGR US Equity","CPK US Equity","MGEE US Equity","NWN US Equity","RGCO US Equity","UTL US Equity","SKI AU Equity","OKE US Equity"))] #Testing for impacts on final sample

#Loop through the scenarios for the base values (Need to choose either daily, weekly or four weekly)


source("Flint analysis - Energy/Estimate_daily_base.r")
source("Flint analysis - Energy/Estimate_weekly_base.r")
source("Flint analysis - Energy/Estimate_fourWeekly_base.r") 

FinDates <- list("2021-07-01","2022-08-01")

EndDate <- dmy("26/08/22")
StartDate <- dmy("01/08/2017")
Sample <- format(EndDate, format = "%Y")

for (i in 1:2){
  
  FinDate <- FinDates[i]
  EstimateDailyBase(EndDate,StartDate,Sample,Firms,FinDate)
  EstimateWeeklyBase(EndDate,StartDate,Sample,Firms,FinDate)
  EstimatefourWeeklyBase(EndDate,StartDate,Sample,Firms,FinDate)
  
}

#Loop through the scenarios for the Covid adjustment (Need to choose either daily, weekly or four weekly)

source("Flint analysis - Energy/Estimate_daily.r")
source("Flint analysis - Energy/Estimate_weekly.r")
source("Flint analysis - Energy/Estimate_fourWeekly.r") 

EndDate <- dmy("26/08/22")
StartDate <- dmy("01/08/2017")
Sample <- format(EndDate, format = "%Y")

Covid_files <- list("17months_10years.csv","17months_15years.csv","17months_20years.csv","17months_50years.csv","17months_100years.csv","30months_10years.csv","30months_15years.csv","30months_20years.csv","30months_50years.csv","30months_100years.csv")

EventsW <- list(2.33,3.68,5.04,13.16,26.7,1.14,1.90,2.66,7.22,14.83)# for weekly
EventsD <- list(2.36,3.73,5.10,13.33,27.04,1.23,2.04,2.84,7.68,15.75)# for daily
EventsM <- list(2.34,3.70,5.07,13.25,26.89,1.16,1.93,2.70,7.34,15.07)# for 4weekly

Covid_dates <- list("2021-06-30","2021-06-30","2021-06-30","2021-06-30","2021-06-30","2022-07-31","2022-07-31","2022-07-31","2022-07-31","2022-07-31")

for (j in 1:10){
  
  Covid_file <- Covid_files[j]
  EventW <- as.numeric(EventsW[j])
  EventD <- as.numeric(EventsD[j])
  EventM <- as.numeric(EventsM[j])
  Covid_date <- Covid_dates[j]
  
  EstimateDaily(EndDate,StartDate,Sample,Firms,Covid_file,EventD,Covid_date)
  EstimateWeekly(EndDate,StartDate,Sample,Firms,Covid_file,EventW,Covid_date)
  EstimateFourWeekly(EndDate,StartDate,Sample,Firms,Covid_file,EventM,Covid_date)
}

#Analyse results

#Read in weekly data

textA <- "months_"
textB <- "years.csv"

text_location <- "Flint analysis - Energy/Results/"
freq <- "Weekly"

data1 <- fread(paste(text_location,freq,"17",textA,"10",textB,sep=""))
data2 <- fread(paste(text_location,freq,"17",textA,"15",textB,sep=""))
data3 <- fread(paste(text_location,freq,"17",textA,"20",textB,sep=""))
data4 <- fread(paste(text_location,freq,"17",textA,"50",textB,sep=""))
data5 <- fread(paste(text_location,freq,"17",textA,"100",textB,sep=""))

data6 <- fread(paste(text_location,freq,"30",textA,"10",textB,sep=""))
data7 <- fread(paste(text_location,freq,"30",textA,"15",textB,sep=""))
data8 <- fread(paste(text_location,freq,"30",textA,"20",textB,sep=""))
data9 <- fread(paste(text_location,freq,"30",textA,"50",textB,sep=""))
data10 <- fread(paste(text_location,freq,"30",textA,"100",textB,sep=""))

data11 <- fread(paste(text_location,"Base_",freq,FinDates[1],".csv",sep=""))
data12 <- fread(paste(text_location,"Base_",freq,FinDates[2],".csv",sep=""))


data1 <- data1[,Code,Assetbeta]
data2 <- data2[,Code,Assetbeta]
data3 <- data3[,Code,Assetbeta]
data4 <- data4[,Code,Assetbeta]
data5 <- data5[,Code,Assetbeta]
data6 <- data6[,Code,Assetbeta]
data7 <- data7[,Code,Assetbeta]
data8 <- data8[,Code,Assetbeta]
data9 <- data9[,Code,Assetbeta]
data10 <- data10[,Code,Assetbeta]
data11 <- data11[,Code,Assetbeta]
data12 <- data12[,Code,Assetbeta]


setnames(data1,"Assetbeta","17months_10years")
setnames(data2,"Assetbeta","17months_15years")
setnames(data3,"Assetbeta","17months_20years")
setnames(data4,"Assetbeta","17months_50years")
setnames(data5,"Assetbeta","17months_100years")
setnames(data6,"Assetbeta","30months_10years")
setnames(data7,"Assetbeta","30months_15years")
setnames(data8,"Assetbeta","30months_20years")
setnames(data9,"Assetbeta","30months_50years")
setnames(data10,"Assetbeta","30months_100years")
setnames(data11,"Assetbeta","NonCovidL")
setnames(data12,"Assetbeta","NonCovidH")

setkey(data1, Code)
setkey(data2, Code)
setkey(data3, Code)
setkey(data4, Code)
setkey(data5, Code)
setkey(data6, Code)
setkey(data7, Code)
setkey(data8, Code)
setkey(data9, Code)
setkey(data10, Code)
setkey(data11, Code)
setkey(data12, Code)

data_weekly <- data11[data12,][data1,][data2,][data3,][data4,][data5,][data6,][data7,][data8,][data9,][data10,]

data_list <- list(data11,data12,data1,data2,data3,data4,data5,data6,data7,data8,data9,data10)

data_weekly$Frequency <- "Weekly"

#Read in daily data

textA <- "months_"
textB <- "years.csv"

text_location <- "Flint analysis - Energy/Results/"
freq <- "Daily"

data1 <- fread(paste(text_location,freq,"17",textA,"10",textB,sep=""))
data2 <- fread(paste(text_location,freq,"17",textA,"15",textB,sep=""))
data3 <- fread(paste(text_location,freq,"17",textA,"20",textB,sep=""))
data4 <- fread(paste(text_location,freq,"17",textA,"50",textB,sep=""))
data5 <- fread(paste(text_location,freq,"17",textA,"100",textB,sep=""))

data6 <- fread(paste(text_location,freq,"30",textA,"10",textB,sep=""))
data7 <- fread(paste(text_location,freq,"30",textA,"15",textB,sep=""))
data8 <- fread(paste(text_location,freq,"30",textA,"20",textB,sep=""))
data9 <- fread(paste(text_location,freq,"30",textA,"50",textB,sep=""))
data10 <- fread(paste(text_location,freq,"30",textA,"100",textB,sep=""))

data11 <- fread(paste(text_location,"Base_",freq,FinDates[1],".csv",sep=""))
data12 <- fread(paste(text_location,"Base_",freq,FinDates[2],".csv",sep=""))


data1 <- data1[,Code,Assetbeta]
data2 <- data2[,Code,Assetbeta]
data3 <- data3[,Code,Assetbeta]
data4 <- data4[,Code,Assetbeta]
data5 <- data5[,Code,Assetbeta]
data6 <- data6[,Code,Assetbeta]
data7 <- data7[,Code,Assetbeta]
data8 <- data8[,Code,Assetbeta]
data9 <- data9[,Code,Assetbeta]
data10 <- data10[,Code,Assetbeta]
data11 <- data11[,Code,Assetbeta]
data12 <- data12[,Code,Assetbeta]


setnames(data1,"Assetbeta","17months_10years")
setnames(data2,"Assetbeta","17months_15years")
setnames(data3,"Assetbeta","17months_20years")
setnames(data4,"Assetbeta","17months_50years")
setnames(data5,"Assetbeta","17months_100years")
setnames(data6,"Assetbeta","30months_10years")
setnames(data7,"Assetbeta","30months_15years")
setnames(data8,"Assetbeta","30months_20years")
setnames(data9,"Assetbeta","30months_50years")
setnames(data10,"Assetbeta","30months_100years")
setnames(data11,"Assetbeta","NonCovidL")
setnames(data12,"Assetbeta","NonCovidH")

setkey(data1, Code)
setkey(data2, Code)
setkey(data3, Code)
setkey(data4, Code)
setkey(data5, Code)
setkey(data6, Code)
setkey(data7, Code)
setkey(data8, Code)
setkey(data9, Code)
setkey(data10, Code)
setkey(data11, Code)
setkey(data12, Code)

data_daily <- data11[data12,][data1,][data2,][data3,][data4,][data5,][data6,][data7,][data8,][data9,][data10,]

data_list <- list(data11,data12,data1,data2,data3,data4,data5,data6,data7,data8,data9,data10)

data_daily$Frequency <- "Daily"


#Read in four four weekly data

textA <- "months_"
textB <- "years.csv"

text_location <- "Flint analysis - Energy/Results/"
freq <- "FourWeekly"

data1 <- fread(paste(text_location,freq,"17",textA,"10",textB,sep=""))
data2 <- fread(paste(text_location,freq,"17",textA,"15",textB,sep=""))
data3 <- fread(paste(text_location,freq,"17",textA,"20",textB,sep=""))
data4 <- fread(paste(text_location,freq,"17",textA,"50",textB,sep=""))
data5 <- fread(paste(text_location,freq,"17",textA,"100",textB,sep=""))

data6 <- fread(paste(text_location,freq,"30",textA,"10",textB,sep=""))
data7 <- fread(paste(text_location,freq,"30",textA,"15",textB,sep=""))
data8 <- fread(paste(text_location,freq,"30",textA,"20",textB,sep=""))
data9 <- fread(paste(text_location,freq,"30",textA,"50",textB,sep=""))
data10 <- fread(paste(text_location,freq,"30",textA,"100",textB,sep=""))

data11 <- fread(paste(text_location,"Base_",freq,FinDates[1],".csv",sep=""))
data12 <- fread(paste(text_location,"Base_",freq,FinDates[2],".csv",sep=""))


data1 <- data1[,Code,Assetbeta]
data2 <- data2[,Code,Assetbeta]
data3 <- data3[,Code,Assetbeta]
data4 <- data4[,Code,Assetbeta]
data5 <- data5[,Code,Assetbeta]
data6 <- data6[,Code,Assetbeta]
data7 <- data7[,Code,Assetbeta]
data8 <- data8[,Code,Assetbeta]
data9 <- data9[,Code,Assetbeta]
data10 <- data10[,Code,Assetbeta]
data11 <- data11[,Code,Assetbeta]
data12 <- data12[,Code,Assetbeta]


setnames(data1,"Assetbeta","17months_10years")
setnames(data2,"Assetbeta","17months_15years")
setnames(data3,"Assetbeta","17months_20years")
setnames(data4,"Assetbeta","17months_50years")
setnames(data5,"Assetbeta","17months_100years")
setnames(data6,"Assetbeta","30months_10years")
setnames(data7,"Assetbeta","30months_15years")
setnames(data8,"Assetbeta","30months_20years")
setnames(data9,"Assetbeta","30months_50years")
setnames(data10,"Assetbeta","30months_100years")
setnames(data11,"Assetbeta","NonCovidL")
setnames(data12,"Assetbeta","NonCovidH")

setkey(data1, Code)
setkey(data2, Code)
setkey(data3, Code)
setkey(data4, Code)
setkey(data5, Code)
setkey(data6, Code)
setkey(data7, Code)
setkey(data8, Code)
setkey(data9, Code)
setkey(data10, Code)
setkey(data11, Code)
setkey(data12, Code)

data_fourweekly <- data11[data12,][data1,][data2,][data3,][data4,][data5,][data6,][data7,][data8,][data9,][data10,]

data_fourweekly$Frequency <- "Four weekly"


#Looking at results after reading in data

data_all <- rbind(data_daily,data_weekly,data_fourweekly)
Results <- as.data.table(data_all)

#Looking for the difference between covid and non-covid results to analyse the difference
# L = low assumption of covid period (17 months); H = high assumption of covid period (30 months)
# We use assumptions of 20 and 50 years for frequency of covid-like events

Results[,LBAvge := (`17months_20years` + `17months_50years`)/2]
Results[,HBAvge := (`30months_20years` + `30months_50years`)/2]
Summary <- Results[,.(Frequency,Code,NonCovidL,NonCovidH,LBAvge,HBAvge)]

#Estimating the difference between base case and covid
Summary[,LBCovidAdj := LBAvge - NonCovidL]
Summary[,HBCovidAdj := HBAvge - NonCovidH]

meanL <- mean(Summary$LBCovidAdj)
meanH <- mean(Summary$HBCovidAdj)

meanL
meanH

#Weekly data only

meanL_weekly <- mean(Summary[Summary$Frequency == 'Weekly', LBCovidAdj])
meanH_weekly <- mean(Summary[Summary$Frequency == 'Weekly', HBCovidAdj])

meanL_weekly
meanH_weekly

write.csv(Summary,"Flint analysis - Energy/Results/Covid_adj_results.csv")
write.csv(Results,"Flint analysis - Energy/Results/Comcom_results.csv")

###Summary of results

Flint_results_energy <- list(meanL,meanH,meanL_weekly,meanH_weekly)
names(Flint_results_energy) <- c("17 month covid difference", "30 month covid difference")
Flint_results_energy

