#Master Gas - testing for difference

#This script runs all the functions in linear order

####Setup####

library(stringr)
library(Rblpapi)
library(dplyr)
library(zoo)
library(tidyr)
library(janitor) 
library(lubridate) 
library(data.table)

#Inputs

Firms <- read.csv("Data/Firms_Energy.csv", header = TRUE, stringsAsFactors = FALSE, strip.white = TRUE) |> #list of comparators
  mutate(Sample_2020 = Sample_2022)    # AS added to make 2-year estimate work

# #Exclude energy firms not in the final sample
Firms <- data.table(Firms)
Firms <- Firms[Code != "AGR US Equity"]
Firms <- Firms[Code != "CPK US Equity"]
Firms <- Firms[Code != "MGEE US Equity"]
Firms <- Firms[Code != "NWN US Equity"]
Firms <- Firms[Code != "RGCO US Equity"]
Firms <- Firms[Code != "UTL US Equity"]
Firms <- Firms[Code != "SKI AU Equity"]
#Firms <- Firms[Code != "OKE US Equity"]

#Loop through the different time periods

source("Gas analysis/Estimate_daily_ttest.r")
source("Gas analysis/Estimate_weekly_ttest.r")
source("Gas analysis/Estimate_fourWeekly_ttest.r")

DateEnds <- list("30/09/2012","30/09/2017","30/09/2022","28/02/2020","28/02/2022", "30/09/2022")
DateStarts <- list("01/10/2007","01/10/2012","01/10/2017","01/10/2017","01/03/2020", "01/10/2021")

 for (j in 1:6) {
   EndDate <- dmy(DateEnds[j])
   StartDate <- dmy(DateStarts[j])
   Sample <- format(EndDate, format = "%Y")

    EstimateDaily(EndDate,StartDate,Sample,Firms)
    EstimateWeekly(EndDate,StartDate,Sample,Firms)
    EstimateFourWeekly(EndDate,StartDate,Sample,Firms)
}


#Analyse results

#Read in weekly data
DateEnds <- list("2012-09-30","2017-09-30","2022-09-30","2020-02-28","2022-02-28", "2022-09-30") 
DateStarts <- list("2007-10-01","2012-10-01","2017-10-01","2017-10-01","2020-03-01","2021-10-01")


text_location <- "Gas analysis/Results/"

data1 <- fread(paste(text_location,"StartDate-",DateStarts[1],"EndDate-",DateEnds[1],"-Daily-TTestResults.csv",sep=""))
data2 <- fread(paste(text_location,"StartDate-",DateStarts[2],"EndDate-",DateEnds[2],"-Daily-TTestResults.csv",sep=""))
data3 <- fread(paste(text_location,"StartDate-",DateStarts[3],"EndDate-",DateEnds[3],"-Daily-TTestResults.csv",sep=""))
data4 <- fread(paste(text_location,"StartDate-",DateStarts[4],"EndDate-",DateEnds[4],"-Daily-TTestResults.csv",sep=""))
data5 <- fread(paste(text_location,"StartDate-",DateStarts[5],"EndDate-",DateEnds[5],"-Daily-TTestResults.csv",sep=""))
data6 <- fread(paste(text_location,"StartDate-",DateStarts[6],"EndDate-",DateEnds[6],"-Daily-TTestResults.csv",sep=""))


data7 <- fread(paste(text_location,"StartDate-",DateStarts[1],"EndDate-",DateEnds[1],"-Weekly-TTestResults.csv",sep=""))
data8 <- fread(paste(text_location,"StartDate-",DateStarts[2],"EndDate-",DateEnds[2],"-Weekly-TTestResults.csv",sep=""))
data9 <- fread(paste(text_location,"StartDate-",DateStarts[3],"EndDate-",DateEnds[3],"-Weekly-TTestResults.csv",sep=""))
data10 <- fread(paste(text_location,"StartDate-",DateStarts[4],"EndDate-",DateEnds[4],"-Weekly-TTestResults.csv",sep=""))
data11 <- fread(paste(text_location,"StartDate-",DateStarts[5],"EndDate-",DateEnds[5],"-Weekly-TTestResults.csv",sep=""))
data12 <- fread(paste(text_location,"StartDate-",DateStarts[6],"EndDate-",DateEnds[6],"-Weekly-TTestResults.csv",sep=""))


data13 <- fread(paste(text_location,"StartDate-",DateStarts[1],"EndDate-",DateEnds[1],"-FourWeekly-TTestResults.csv",sep=""))
data14 <- fread(paste(text_location,"StartDate-",DateStarts[2],"EndDate-",DateEnds[2],"-FourWeekly-TTestResults.csv",sep=""))
data15 <- fread(paste(text_location,"StartDate-",DateStarts[3],"EndDate-",DateEnds[3],"-FourWeekly-TTestResults.csv",sep=""))
data16 <- fread(paste(text_location,"StartDate-",DateStarts[4],"EndDate-",DateEnds[4],"-FourWeekly-TTestResults.csv",sep=""))
data17 <- fread(paste(text_location,"StartDate-",DateStarts[5],"EndDate-",DateEnds[5],"-FourWeekly-TTestResults.csv",sep=""))
data18 <- fread(paste(text_location,"StartDate-",DateStarts[6],"EndDate-",DateEnds[6],"-FourWeekly-TTestResults.csv",sep=""))

data1 <- data1[,3]
data2 <- data2[,3]
data3 <- data3[,3]
data4 <- data4[,3]
data5 <- data5[,3]
data6 <- data6[,3]
data7 <- data7[,3]
data8 <- data8[,3]
data9 <- data9[,3]
data10 <- data10[,3]
data11 <- data11[,3]
data12 <- data12[,3]
data13 <- data13[,3]
data14 <- data14[,3]
data15 <- data15[,3]
data16 <- data16[,3]
data17 <- data17[,3]
data18 <- data18[,3]


setnames(data1,"p_value","2007-12")
setnames(data2,"p_value","2012-17")
setnames(data3,"p_value","2017-22")
setnames(data4,"p_value","2017-20")
setnames(data5,"p_value","2020-22")
setnames(data6,"p_value","2021-22")

Daily <- cbind(data1,data2,data3,data4,data5,data6)
Daily$Frequency <- "Daily"

setnames(data7,"p_value","2007-12")
setnames(data8,"p_value","2012-17")
setnames(data9,"p_value","2017-22")
setnames(data10,"p_value","2017-20")
setnames(data11,"p_value","2020-22")
setnames(data12,"p_value","2021-22")

Weekly <- cbind(data7,data8,data9,data10,data11,data12)
Weekly$Frequency <- "Weekly"

setnames(data13,"p_value","2007-12")
setnames(data14,"p_value","2012-17")
setnames(data15,"p_value","2017-22")
setnames(data16,"p_value","2017-20")
setnames(data17,"p_value","2020-22")
setnames(data18,"p_value","2021-22")

Four_weekly <- cbind(data13,data14,data15,data16,data17,data18)
Four_weekly$Frequency <- "Four_weekly"

Summary <- rbind(Daily, Weekly, Four_weekly)
Summary #p-values of difference between gas and non-gas for different frequencies and time periods

write.csv(Summary,"Gas analysis/Results/Summary_Ttests.csv")

###Gas vs non-gas credit ratings###

#t-test for gas subs-sample
Creditrating <- read.csv("Data/Industry_credit_rating.csv")
#FullSample1 <- FullResults #This is only for the gas companies
FullSample <- left_join(Firms,Creditrating, by = "Code")
FullSample <- data.table(FullSample)
mapping <- c("BB-" = 1, "BB" = 2, "BB+" = 3, "BBB-" = 4, "BBB" = 5, "BBB+" = 6, "A-" = 7, "A" = 8, "AA-" = 9)

#Gas sample
GasSample <- FullSample[Industry == "Gas"]
#Add in column for numbers to represent credit rating in order
GasSample$value <- mapping[GasSample$Credit.rating]
GasSample <- na.omit(GasSample)

#Non-gas sample
NonGasSample <- FullSample[Industry != "Gas"]
NonGasSample <- NonGasSample[Code != "HE US Equity"] #Due to recent wildfires the credit rating has been dramatically cut and is on credit watch, not usual circumstances to compare
#Add in column for numbers to represent credit rating in order
NonGasSample$value <- mapping[NonGasSample$Credit.rating]
NonGasSample <- na.omit(NonGasSample)

mean(GasSample$value)
mean(NonGasSample$value)

#Plot credit ratings
plot(density(NonGasSample$value), main = "Gas and non-gas credit ratings", col = "blue", xaxt="n", xlab="Credit ratings")
lines(density(GasSample$value), col = "red")
legend("topleft", c("Non Gas","Gas"), lty = c(1,1), col = c("blue","red"))
x=c("BB-", "BB", "BB+", "BBB-", "BBB", "BBB+", "A-", "A", "AA-")
axis(1, at=floor(seq(1,9,length=9)), labels=x)


